import { h, } from '@vue/runtime-core';
import { NSVRoot } from './dom';
import { renderer } from './renderer';
const __DEV__ = true;
let rootContext = null;
export const setRootContext = (context) => {
    rootContext = context;
};
export const createNativeView = (component, props, contextOverrides) => {
    let vnode;
    let isMounted = false;
    let container;
    const context = { ...rootContext, ...contextOverrides };
    return {
        context,
        get nativeView() {
            return vnode.el.nativeView;
        },
        mount(root = new NSVRoot()) {
            if (isMounted) {
                return vnode;
            }
            vnode = h(component, props);
            vnode.appContext = context;
            renderer.render(vnode, root);
            isMounted = true;
            container = root;
            return vnode;
        },
        unmount() {
            if (!isMounted)
                return;
            vnode = null;
            renderer.render(null, container);
            isMounted = false;
            container = null;
        },
    };
};
export const ELEMENT_REF = Symbol(__DEV__ ? `elementRef` : ``);
const onRE = /^on.+/;
export const isOn = (key) => onRE.test(key);
export const isAndroidKey = (key) => key.startsWith('android:');
export const isIOSKey = (key) => key.startsWith('ios:');
export const isBoolean = (value) => {
    return typeof value === 'boolean' || value instanceof Boolean;
};
//# sourceMappingURL=runtimeHelpers.js.map